@@ -4,4 +4,6 @@ TARGET_LINE_LENGHT = 60
 SPACES_LEVEL_INDENTATION = "   "
 COMMENT_INI = "# "
 POSITIVE_CLOSURE = "+"
-KLEENE_CLOSURE = "*"
\ No newline at end of file
+KLEENE_CLOSURE = "*"
+OPT_CARDINALITY = "?"
+SHAPE_LINK_CHAR = "@"
\ No newline at end of file
